# Outbound Processors
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/outbound-processors#overview)
  * [Setting the Scope](https://help.sap.com/docs/leanix/ea/outbound-processors#setting-the-scope)
  * [Setting the Fields](https://help.sap.com/docs/leanix/ea/outbound-processors#setting-the-fields)
  * [Setting Filters](https://help.sap.com/docs/leanix/ea/outbound-processors#setting-filters)
  * [Outbound Fact Sheet](https://help.sap.com/docs/leanix/ea/outbound-processors#outbound-fact-sheet)
  * [Exporting Relations](https://help.sap.com/docs/leanix/ea/outbound-processors#exporting-relations)
  * [Exporting All Relations and Fields within Relations](https://help.sap.com/docs/leanix/ea/outbound-processors#exporting-all-relations-and-fields-within-relations)
  * [Exporting Constraining Relations](https://help.sap.com/docs/leanix/ea/outbound-processors#exporting-constraining-relations)


View all
**Caution**
We recommend to use the [Write to LDIF](https://help.sap.com/docs/leanix/ea/inbound-processors?locale=en-US&state=PRODUCTION&version=CLOUD#loio275a8a067a4410148b1fcfe89dcdedca__write_to_ldif) inbound processor to export data as LDIF.
